==> typeit-7.0.4.tgz: package/README.md <==
# TypeIt

The Most Versatile JavaScript Animated Typing Utility on the Planet

[![Build Status](https://travis-ci.org/alexmacarthur/typeit.svg?branch=master)](https://travis-ci.org/alexmacarthur/typeit)
[![npm downloads](https://img.shields.io/npm/dm/typeit.svg?style=flat-square)](http://npm-stat.com/charts.html?package=typeit)
[![](https://data.jsdelivr.com/v1/package/npm/typeit/badge)](https://www.jsdelivr.com/package/npm/typeit)
[![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?url=https%3A%2F%2Fgithub.com%2Falexmacarthur%2Ftypeit&via=amacarthur&text=Check%20out%20TypeIt%2C%20the%20most%20versatile%20JavaScript%20animated%20typing%20utility%20on%20the%20planet.&hashtags=js%2Cwebdev%2Coss)

<p align="center">
    <img src="readme-demo.gif" alt="" style="border: 5px solid #24292e;">
</p>

## Overview

TypeIt is the most versatile JavaScript typewriter effect utility on the planet. With its simple yet flexible configuration, you're empowerd to type single or multiple strings that break lines, delete & replace each other, easily handle string containing HTML, loop, and a whole lot more.

For more advanced, controlled typing effects, TypeIt comes with companion functions that can be chained to control your typing down to a single character or millisecond, enabling you to type an dynamic narrative, with complete reign over speed changes, line breaks, deletions, and pauses.

## Key Features

-   Choose to start typing only when your target element becomes visible on the screen.
-   Loop your string(s) continuously.
-   Define your strings via an options object or in the HTML (a useful fallback in case user doesn't have JavaScript enabled, as well as for SEO).
-   Use a single TypeIt instance to target several different elements on a page.
-   Handle HTML (even nested tags!) with ease, preserving all of its attributes (classes, ids, etc.).
-   Use companion functions to chain individual commands together to fine tune your typing.
-   Ready to be included via JS module, or as a separate script loaded on your page (both "legacy" and modern bundles are provided).
-   No dependencies!

## License Options

Using TypeIt for an open source or personal project is completely free. To use it in a commercial project, purchase a single license, or an unlimited license that'll never expire, no matter how many times you use it.

-   Single Commercial License - [Purchase Here](https://typeitjs.com/checkout/limited)
-   Extended Commercial License - [Purchase Here](https://typeitjs.com/checkout/unlimited)

## Demos

See some more examples and try out the sandbox at [https://typeitjs.com](https://typeitjs.com).

## Documentation

All of TypeIt's documentation can be found at [https://typeitjs.com/docs](https://typeitjs.com/docs).

## Looking for a React Component?

Check out the official [React component for TypeIt](https://github.com/alexmacarthur/typeit-react) here.

## Contribute

Please do! The code is available on Github. Check out the [CONTRIBUTING.md](https://github.com/alexmacarthur/typeit/blob/master/CONTRIBUTING.md) file to see how to get started.

## Know of a Neat Site Using TypeIt?

I'd love to see and share it! [Send me a message](https://macarthur.me/contact) or [tweet at me.](https://www.twitter.com/amacarthur)

## Need Help?

If you're working with a custom implementation of TypeIt and would like some help, I'm available for hire. [Get in touch!](https://macarthur.me/contact)

## License

[GPL-2.0](https://github.com/alexmacarthur/typeit/blob/master/LICENSE) © Alex MacArthur

==> typeit-8.0.3.tgz: package/README.md <==
# TypeIt

The Most Versatile JavaScript Animated Typing Utility on the Planet

[![Bundle Size](https://badgen.net/bundlephobia/minzip/typeit)](https://bundlephobia.com/result?p=typeit)
[![npm downloads](https://img.shields.io/npm/dm/typeit.svg?style=flat-square)](http://npm-stat.com/charts.html?package=typeit)
[![](https://data.jsdelivr.com/v1/package/npm/typeit/badge)](https://www.jsdelivr.com/package/npm/typeit)
[![Tweet](https://img.shields.io/twitter/url/http/shields.io.svg?style=social)](https://twitter.com/intent/tweet?url=https%3A%2F%2Fgithub.com%2Falexmacarthur%2Ftypeit&via=amacarthur&text=Check%20out%20TypeIt%2C%20the%20most%20versatile%20JavaScript%20animated%20typing%20utility%20on%20the%20planet.&hashtags=js%2Cwebdev%2Coss)

<p align="center">
    <img src="readme-demo.gif" alt="" style="border: 5px solid #24292e;">
</p>

## Overview

TypeIt is the most versatile JavaScript typewriter effect utility on the planet. With its simple yet flexible configuration, you're empowerd to type single or multiple strings that break lines, delete & replace each other, easily handle string containing HTML, loop, and a whole lot more.

For more advanced, controlled typing effects, TypeIt comes with companion functions that can be chained to control your typing down to a single character or millisecond, enabling you to type an dynamic narrative, with complete reign over speed changes, line breaks, deletions, and pauses.

## Key Features

-   Choose to start typing only when your target element becomes visible on the screen.
-   Loop your string(s) continuously.
-   Set strings to type via an options object or in the HTML (a useful fallback in case user doesn't have JavaScript enabled, as well as for SEO).
-   Use a single TypeIt instance to target several different elements on a page.
-   Handle HTML (even nested tags!) with ease, preserving all of its attributes (classes, ids, etc.).
-   Use companion functions to chain individual commands together to fine tune your typing.
-   Ready to be included via JS module, or as a separate script loaded on your page (both "legacy" and modern bundles are provided).
-   No dependencies!

## License Options

Using TypeIt for an open source or personal project is completely free is licensed under [GPLv3](https://www.gnu.org/licenses/quick-guide-gplv3.html). To use it in a commercial project, however, a paid license is required. Learn more about them here:

-   Single Commercial License - [Purchase Here](https://typeitjs.com/checkout/limited)
-   Extended Commercial License - [Purchase Here](https://typeitjs.com/checkout/unlimited)

## Demos

See some more examples and try out the sandbox at [https://typeitjs.com](https://typeitjs.com).

## Documentation

All of TypeIt's documentation can be found at [https://typeitjs.com/docs](https://typeitjs.com/docs).

## Looking for a React Component?

Check out the official [React component for TypeIt](https://github.com/alexmacarthur/typeit-react) here.

## Contribute

Please do! Check out the [CONTRIBUTING.md](https://github.com/alexmacarthur/typeit/blob/master/CONTRIBUTING.md) file to see how to get started.

## Know of a Neat Site Using TypeIt?

I'd love to see and share it! [Send me a message](https://macarthur.me/contact) or [tweet at me.](https://www.twitter.com/amacarthur)

## Need Help?

If you're working with a custom implementation of TypeIt and would like some help, I'm available for hire. [Get in touch!](https://macarthur.me/contact)
